==> XoopsHP1.1.zip: XoopsHP1.1/module/XoopsHP/admin/update.php <==
<?php
// $Id$
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

include '../module_prefix.php';
include_once '../../../include/cp_header.php';
xoops_cp_header();

if ( file_exists("../language/".$xoopsConfig['language']."/main.php") ) {
    include "../language/".$xoopsConfig['language']."/main.php";
} else {
    include "../language/english/main.php";
}

if (is_object($xoopsUser) && $xoopsUser->isAdmin($xoopsModule->mid())) {
	$errors=0;
	$sql=sprintf("ALTER TABLE " . $xoopsDB->prefix($module_prefix."_quiz") . " ADD   display TINYINT NOT NULL DEFAULT  '1', ADD  expire DATETIME NOT NULL DEFAULT  '0000-00-00 00:00:00';");
	$result=$xoopsDB->queryF($sql);
	if (!$result) {
    	echo '<br />' .  _AM_MSG_UPDATE_FAILED;
    	$errors++;
	}

	$sql=sprintf("ALTER TABLE " . $xoopsDB->prefix($module_prefix."_sections") . " ADD   display TINYINT NOT NULL DEFAULT  '1', ADD  expire DATETIME NOT NULL DEFAULT  '0000-00-00 00:00:00';");
	$result=$xoopsDB->queryF($sql);
	if (!$result) {
    	echo '<br />' .  _AM_MSG_UPDATE_FAILED;
    	$errors++;
	}

	
	if($errors) {
		echo "<H1>" . _AM_NEWS_UPGRADEFAILED . "</H1>";
	} else {
		echo _AM_MSG_UPDATE_SUCCEEDED;
	}
} else {
	printf("<H2>%s</H2>\n",__AM_MSG_ACCESS_ERROR);
}

xoops_cp_footer();
?>

==> XoopsHP1.12.zip: XoopsHP1.12/module/XoopsHP/admin/update.php <==
<?php
// $Id$
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

include '../../../include/cp_header.php';
xoops_cp_header();

	echo "<H2>No need to call this script by hand.  Please simply update the module</H2>\n";
	echo "<H2>W[̃Abvf[ĝ݂ŁA蓮ł̃Abvf[g͕svłB</H2>\n";

xoops_cp_footer();
?>
